@@ -1,5 +1,3 @@
-# Copyright (C) Dnspython Contributors, see LICENSE for text of ISC license
-
 # Copyright (C) 2003-2007, 2009-2011 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
@@ -16,13 +14,8 @@
 # OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 import dns.rdtypes.nsbase
-import dns.immutable
 
-
-@dns.immutable.immutable
 class DNAME(dns.rdtypes.nsbase.UncompressedNS):
-
     """DNAME record"""
-
-    def _to_wire(self, file, compress=None, origin=None, canonicalize=False):
-        self.target.to_wire(file, None, origin, canonicalize)
+    def to_digestable(self, origin = None):
+        return self.target.to_digestable(origin)
