@@ -1,6 +1,4 @@
-# Copyright (C) Dnspython Contributors, see LICENSE for text of ISC license
-
-# Copyright (C) 2003-2017 Nominum, Inc.
+# Copyright (C) 2003-2007, 2009-2011 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -15,37 +13,35 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 # OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-import binascii
-import codecs
+import io
 import struct
 
 import dns.exception
-import dns.immutable
-import dns.ipv4
-import dns.ipv6
+import dns.inet
 import dns.rdata
 import dns.tokenizer
+import dns.util
 
+class APLItem(object):
+    """An APL list item.
 
-@dns.immutable.immutable
-class APLItem:
+    @ivar family: the address family (IANA address family registry)
+    @type family: int
+    @ivar negation: is this item negated?
+    @type negation: bool
+    @ivar address: the address
+    @type address: string
+    @ivar prefix: the prefix length
+    @type prefix: int
+    """
 
-    """An APL list item."""
-
-    __slots__ = ["family", "negation", "address", "prefix"]
+    __slots__ = ['family', 'negation', 'address', 'prefix']
 
     def __init__(self, family, negation, address, prefix):
-        self.family = dns.rdata.Rdata._as_uint16(family)
-        self.negation = dns.rdata.Rdata._as_bool(negation)
-        if self.family == 1:
-            self.address = dns.rdata.Rdata._as_ipv4_address(address)
-            self.prefix = dns.rdata.Rdata._as_int(prefix, 0, 32)
-        elif self.family == 2:
-            self.address = dns.rdata.Rdata._as_ipv6_address(address)
-            self.prefix = dns.rdata.Rdata._as_int(prefix, 0, 128)
-        else:
-            self.address = dns.rdata.Rdata._as_bytes(address, max_length=127)
-            self.prefix = dns.rdata.Rdata._as_uint8(prefix)
+        self.family = family
+        self.negation = negation
+        self.address = address
+        self.prefix = prefix
 
     def __str__(self):
         if self.negation:
@@ -55,11 +51,11 @@ class APLItem:
 
     def to_wire(self, file):
         if self.family == 1:
-            address = dns.ipv4.inet_aton(self.address)
+            address = dns.inet.inet_pton(dns.inet.AF_INET, self.address)
         elif self.family == 2:
-            address = dns.ipv6.inet_aton(self.address)
+            address = dns.inet.inet_pton(dns.inet.AF_INET6, self.address)
         else:
-            address = binascii.unhexlify(self.address)
+            address = self.address.decode('hex_codec')
         #
         # Truncate least significant zero bytes.
         #
@@ -68,86 +64,108 @@ class APLItem:
             if address[i] != 0:
                 last = i + 1
                 break
-        address = address[0:last]
+        address = address[0 : last]
         l = len(address)
         assert l < 128
         if self.negation:
             l |= 0x80
-        header = struct.pack("!HBB", self.family, self.prefix, l)
+        header = struct.pack('!HBB', self.family, self.prefix, l)
         file.write(header)
         file.write(address)
 
-
-@dns.immutable.immutable
 class APL(dns.rdata.Rdata):
+    """APL record.
 
-    """APL record."""
+    @ivar items: a list of APL items
+    @type items: list of APL_Item
+    @see: RFC 3123"""
 
-    # see: RFC 3123
-
-    __slots__ = ["items"]
+    __slots__ = ['items']
 
     def __init__(self, rdclass, rdtype, items):
-        super().__init__(rdclass, rdtype)
-        for item in items:
-            if not isinstance(item, APLItem):
-                raise ValueError("item not an APLItem")
-        self.items = tuple(items)
+        super(APL, self).__init__(rdclass, rdtype)
+        self.items = items
 
     def to_text(self, origin=None, relativize=True, **kw):
-        return " ".join(map(str, self.items))
+        return ' '.join(map(lambda x: str(x), self.items))
 
-    @classmethod
-    def from_text(
-        cls, rdclass, rdtype, tok, origin=None, relativize=True, relativize_to=None
-    ):
+    def from_text(cls, rdclass, rdtype, tok, origin = None, relativize = True):
         items = []
-        for token in tok.get_remaining():
-            item = token.unescape().value
-            if item[0] == "!":
+        while 1:
+            token = tok.get().unescape()
+            if token.is_eol_or_eof():
+                break
+            item = token.value
+            if item[0] == '!':
                 negation = True
                 item = item[1:]
             else:
                 negation = False
-            (family, rest) = item.split(":", 1)
+            (family, rest) = item.split(':', 1)
             family = int(family)
-            (address, prefix) = rest.split("/", 1)
+            (address, prefix) = rest.split('/', 1)
             prefix = int(prefix)
             item = APLItem(family, negation, address, prefix)
             items.append(item)
 
         return cls(rdclass, rdtype, items)
 
-    def _to_wire(self, file, compress=None, origin=None, canonicalize=False):
+    from_text = classmethod(from_text)
+
+    def to_wire(self, file, compress = None, origin = None):
         for item in self.items:
             item.to_wire(file)
 
-    @classmethod
-    def from_wire_parser(cls, rdclass, rdtype, parser, origin=None):
-
+    def from_wire(cls, rdclass, rdtype, wire, current, rdlen, origin = None):
         items = []
-        while parser.remaining() > 0:
-            header = parser.get_struct("!HBB")
+        while 1:
+            if rdlen < 4:
+                raise dns.exception.FormError
+            header = struct.unpack('!HBB', wire[current : current + 4])
             afdlen = header[2]
             if afdlen > 127:
                 negation = True
                 afdlen -= 128
             else:
                 negation = False
-            address = parser.get_bytes(afdlen)
+            current += 4
+            rdlen -= 4
+            if rdlen < afdlen:
+                raise dns.exception.FormError
+            address = wire[current : current + afdlen].unwrap()
             l = len(address)
             if header[0] == 1:
                 if l < 4:
-                    address += b"\x00" * (4 - l)
+                    address += b'\x00' * (4 - l)
+                address = dns.inet.inet_ntop(dns.inet.AF_INET, address)
             elif header[0] == 2:
                 if l < 16:
-                    address += b"\x00" * (16 - l)
+                    address += b'\x00' * (16 - l)
+                address = dns.inet.inet_ntop(dns.inet.AF_INET6, address)
             else:
                 #
                 # This isn't really right according to the RFC, but it
                 # seems better than throwing an exception
                 #
-                address = codecs.encode(address, "hex_codec")
+                address = dns.rdata._hexify(address)
+            current += afdlen
+            rdlen -= afdlen
             item = APLItem(header[0], negation, address, header[1])
             items.append(item)
+            if rdlen == 0:
+                break
         return cls(rdclass, rdtype, items)
+
+    from_wire = classmethod(from_wire)
+
+    def _cmp(self, other):
+        f = io.BytesIO()
+        self.to_wire(f)
+        wire1 = f.getvalue()
+        f.seek(0)
+        f.truncate()
+        other.to_wire(f)
+        wire2 = f.getvalue()
+        f.close()
+
+        return dns.util.cmp(wire1, wire2)
