@@ -1,6 +1,4 @@
-# Copyright (C) Dnspython Contributors, see LICENSE for text of ISC license
-
-# Copyright (C) 2003-2017 Nominum, Inc.
+# Copyright (C) 2003-2007, 2009-2011 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -19,21 +17,18 @@
 
 import dns.exception
 
-
 class BadTTL(dns.exception.SyntaxError):
-    """DNS TTL value is not well-formed."""
-
+    pass
 
 def from_text(text):
     """Convert the text form of a TTL to an integer.
 
     The BIND 8 units syntax for TTLs (e.g. '1w6d4h3m10s') is supported.
 
-    *text*, a ``str``, the textual TTL.
-
-    Raises ``dns.ttl.BadTTL`` if the TTL is not well-formed.
-
-    Returns an ``int``.
+    @param text: the textual TTL
+    @type text: string
+    @raises dns.ttl.BadTTL: the TTL is not well-formed
+    @rtype: int
     """
 
     if text.isdigit():
